/*
 * @(#)Signature.h    1.00   08/15/03
 *
 * Copyright (c) 2003-2006 Agilis Software LLC, Santa Clara, CA, U.S.A.
 * All rights reserved.
 *
 * This software is the confidential and proprietary information
 * of Agilis Software LLC ("Confidential Information").  You shall not
 * disclose such Confidential Information and shall use it only
 * in accordance with the terms of the license agreement you entered
 * into with Agilis Software LLC.
 */
#ifndef __SIGNATURE_H
#define __SIGNATURE_H

#include <IlsPlat.h>

#ifdef __cplusplus
extern "C" {
#endif


#define SIGBUFSIZE	2048

/* Return codes for makeLibDigest */
#define ILS_SIG_STATUS_OK		0	// success
#define ILS_SIG_STATUS_CANT_FIND_LIB	-1	// unable to locate library
#define ILS_SIG_STATUS_BUFFER_OVERFLOW	-2	// application error: signature / password buffer too small
#define ILS_SIG_STATUS_LIB_NAME_TOO_LONG	-3	// application error: library name too long
#define ILS_SIG_STATUS_LIB_FILENAME_TOO_LONG	-4	// application error: library file name too long
#define ILS_SIG_STATUS_INVALID_LIBFILE	-5 // invalid or empty library file
#define ILS_SIG_STATUS_INVALID_CREDENTIALS	-6 // invalid library product name / password - doesn't match what was used to generate signature
#define ILS_SIG_STATUS_INTERNAL_ERROR	-1000 // internal error: report to Agilis


/**
 * Make an encrypted library digest (signature) for a specified shared
 * library file of a specified product based on a specified secret password. 
 * Also make public-key-encrypted versions of the signature and the
 * password for secure persistent storage or embedding in the
 * application, if the call is in the ISV's development environment.
 * @param libName: base file name for the shared library, excluding
 *     directory prefix and file extension.
 *    The application's PATH environment variable should be set up 
 *    so that the jar can be found.
 * @param password: application password, assumed encrypted with the
 *    product's public key if this is invoked at an end customer's
 *    run time environment.
 * @param libProductName: name of the library product.
 * @param isvEnvironment: whether invoked in ISV environment.
 * @param strSignatureBuf: buffer to receive signature
 * @param signatureBufsize: size of signature buffer
 * @param strEncodedSigBuf: buffer to receive public-key-encrypted signature
 * @param encodedSigBufsize: size of public-key-encrypted signature buffer
 * @param strEncodedPwdBuf: buffer to receive public-key-encrypted pasword
 * @param encodedPwdBufsize: size of public-key-encrypted password buffer
 * @return status: ILS_SIG_STATUS_OK (0) if success, ILS_SIG_STATUS_* (a negative 
 *        status code, defined above) otherwise.  
 *        If a negative status code is returned,
 *        the associated error text is deposited in the signature buffer.
 **/
DLLEXPORT int CALLING_CONVENTION makeLibDigest(const char *libName,
									 const char *password,
									 const char *libProductName,
									 boolean isvEnvironment,
									 char strSignatureBuf[],
									 size_t signatureBufsize,
									 char strEncodedSigBuf[],
									 size_t encodedSigBufsize,
									 char strEncodedPwdBuf[],
									 size_t encodedPwdBufsize);


#ifdef __cplusplus
}
#endif


#endif

